/* This file is part of Eclat.
   Copyright (C) 2012-2015 Sergey Poznyakoff.
 
   Eclat is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.
 
   Eclat is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with Eclat.  If not, see <http://www.gnu.org/licenses/>. */

#include <grecs.h>

enum json_object_type
{
	json_null,
	json_bool,
	json_number,
	json_string,
	json_arr,
	json_obj
};

struct json_object;
struct json_array {
	size_t oc;
	struct json_object **ov;
};

struct json_object {
	enum json_object_type type;
	union {
		int b;                  /* json_bool */
		double n;               /* json_number */
		char *s;                /* json_string */
		struct json_array *a;   /* json_arr */
		struct grecs_symtab *o; /* json_o */
	} v;
};

struct json_pair {
	char *k;
	struct json_object *v;
};

extern char const *json_err_diag;
extern char const *json_err_ptr;
extern struct json_object *json_return_obj;

void jsonlex_setup(char const *s, size_t l);
void jsonlex_diag(const char *s, size_t off);
struct json_object *json_object_create(int type);
struct grecs_symtab *json_assoc_create(void);
void json_object_free(struct json_object *obj);

struct json_object *json_parse_string(char const *input, size_t len);

struct json_object *json_object_lookup(struct json_object *obj,
				       const char *ident);


